% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sim.load.R
\name{sim.load}
\alias{sim.load}
\title{Provides Access to the Declarations of Death (Children) Dataset from the Mortality Information System (SIM).}
\usage{
sim.load(types, years, states = "", language = datasus.lang(),
  fields = NA)
}
\arguments{
\item{types}{character; an array with any combination of the supported types: DO, DOFET, DOINF, DOMAT, DOEXT.}

\item{years}{numeric; one or more years representing the data to be read}

\item{states}{character; one or more state (UF) representing the location of the data to be read, or 'ALL' if you want to read data from all states (UFs) at the same time. Only valid for the DO type.}

\item{language}{character; column names in Portuguese ("pt") or English ("en"). Default is "en".}
}
\value{
a data.frame with Brazil's mortality data
}
\description{
\code{sim.load} returns a data.frame with a subset of the Declarations of Death dataset from the selected types (categories).
}
\details{
The Mortality Information System (SIM) offers health managers, researchers and institutions highly relevant information for defining priorities for disease prevention and control programmes, based on death statement information collected by the State Health Departments. The national Database generated from this information is administered by the Health Surveillance Secretariat in cooperation with DATASUS.

The system works through the filling in and collection of a standard document, the Death Statement (Declaration of Death), which is entered onto the system in the states and municipalities. The data collected is of great importance for health surveillance and epidemiological analysis, as well as health and demographical statistics.

This system contains data divided in the following categories:

\itemize{
 \item DO: Declarations of death  
 \item DOFET: Declarations of death (Fetal)  
 \item DOEXT: Declarations of death (External Causes)  
 \item DOINF: Declarations of death (Children)  
 \item DOMAT: Declarations of death (Maternal)
}

The \code{sim.*} functions are provided for each available subsystem, for example, \code{sim.dofet}, \code{sim.doext} and so on.
}
\note{
DATASUS is the name of the Department of Informatics of the Brazilian Unified Health System (SUS) and is resposible for publishing public healthcare data. Besides the DATASUS, the Brazilian National Agency for Supplementary Health (ANS) also uses this file format for its public data. The name DATASUS is also often used to represent the public datasets they provide.

Neither this project, nor its author, has any association with the brazilian government.
}
\examples{

# Loads Maternal Deaths for 2010
domat10 <- sim.load('DOMAT', 2010)

# Loads Fetal Deaths for 2012
dofet12 <- sim.load('DOFET', 2012)

# Loads Fetal and Infant Deaths for 2010 with ALL fields selected (field naming only available in Portuguese)
do2010  <- sim.load(c('DOFET','DOINF'), 2010, fields = 'ALL')

}
\author{
Daniela Petruzalek, \email{daniela.petruzalek@gmail.com}
}
\seealso{
\code{\link{datasus.init}} \code{\link{read.dbc}}
}
\keyword{datasus}

